pub fn open_u3v_device<T: UsbTransfer + 'static>(
device: U3vDevice<T>,
) -> Result<(Camera<U3vRegisterIo<T>>, String), GenicamError>Expand description
Create a Camera from an already-opened U3vDevice
with any UsbTransfer backend.
This is the generic entry point for testing with fake or mock transports. The device must have been opened and bootstrapped (ABRM/SBRM read) before calling this function.